==> haskell-os-string-2.0.8-86-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-os-string.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 os-string
version:              2.0.8
visibility:           public
id:                   os-string-2.0.8-96hzC853MquDVlq6baUeGP
key:                  os-string-2.0.8-96hzC853MquDVlq6baUeGP
license:              BSD-3-Clause
copyright:            Julain Ospald 2021-2023
maintainer:           Julian Ospald <hasufell@posteo.de>
author:               Julian Ospald <hasufell@posteo.de>
homepage:             https://github.com/haskell/os-string/blob/master/README.md
synopsis:             Library for manipulating Operating system strings.
description:
    This package provides functionality for manipulating @OsString@ values, and is shipped with <https://www.haskell.org/ghc/ GHC>.

category:             System
abi:                  b96426907bbde9d563ab62f4d3b308f0
exposed:              True
exposed-modules:
    System.OsString System.OsString.Data.ByteString.Short
    System.OsString.Data.ByteString.Short.Internal
    System.OsString.Data.ByteString.Short.Word16
    System.OsString.Encoding System.OsString.Encoding.Internal
    System.OsString.Internal System.OsString.Internal.Exception
    System.OsString.Internal.Types System.OsString.Posix
    System.OsString.Windows

import-dirs:          /usr/lib/ghc-9.6.6/site-local/os-string-2.0.8
library-dirs:         /usr/lib/ghc-9.6.6/site-local/os-string-2.0.8
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/os-string-2.0.8
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-os-string
hs-libraries:         HSos-string-2.0.8-96hzC853MquDVlq6baUeGP
depends:
    base-4.18.2.1 bytestring-0.11.5.3 deepseq-1.4.8.1 exceptions-0.10.7
    template-haskell-2.20.0.0

haddock-interfaces:   /usr/share/doc/haskell-os-string/html/os-string.haddock
haddock-html:         /usr/share/doc/haskell-os-string/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-os-string-2.0.8-88-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-os-string.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 os-string
version:              2.0.8
visibility:           public
id:                   os-string-2.0.8-D0wNnGg8ZcR9R5RCvHxlBy
key:                  os-string-2.0.8-D0wNnGg8ZcR9R5RCvHxlBy
license:              BSD-3-Clause
copyright:            Julain Ospald 2021-2023
maintainer:           Julian Ospald <hasufell@posteo.de>
author:               Julian Ospald <hasufell@posteo.de>
homepage:             https://github.com/haskell/os-string/blob/master/README.md
synopsis:             Library for manipulating Operating system strings.
description:
    This package provides functionality for manipulating @OsString@ values, and is shipped with <https://www.haskell.org/ghc/ GHC>.

category:             System
abi:                  072c6b7abbe9dbc74b9838b0ee1a31ac
exposed:              True
exposed-modules:
    System.OsString System.OsString.Data.ByteString.Short
    System.OsString.Data.ByteString.Short.Internal
    System.OsString.Data.ByteString.Short.Word16
    System.OsString.Encoding System.OsString.Encoding.Internal
    System.OsString.Internal System.OsString.Internal.Exception
    System.OsString.Internal.Types System.OsString.Posix
    System.OsString.Windows

import-dirs:          /usr/lib/ghc-9.6.6/site-local/os-string-2.0.8
library-dirs:         /usr/lib/ghc-9.6.6/site-local/os-string-2.0.8
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/os-string-2.0.8
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-os-string
hs-libraries:         HSos-string-2.0.8-D0wNnGg8ZcR9R5RCvHxlBy
depends:
    base-4.18.2.1 bytestring-0.11.5.3 deepseq-1.4.8.1 exceptions-0.10.7
    template-haskell-2.20.0.0

haddock-interfaces:   /usr/share/doc/haskell-os-string/html/os-string.haddock
haddock-html:         /usr/share/doc/haskell-os-string/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
